import Aggregate from "omni.models/model/aggregate";
import { RuleBehaviour } from "omni.interfaces/types";
import { RuleStructureInterface } from "omni.interfaces";
export declare function load(name: string, version: string, rules: RuleStructureInterface[], schemaVersion: string): RulesEngine;
export declare function getEngine(name: string, version: string): RulesEngine;
export declare const engines: {
    load: typeof load;
    loadDecisionObject(ds: Aggregate): void;
    getEngine: typeof getEngine;
    registry: {
        [name: string]: {
            [version: string]: RulesEngine;
        };
    };
};
export declare class RuleInstance {
    name: string;
    code: string;
    variables: string[];
    behaviour: RuleBehaviour;
    ruleCode: string;
    path: {
        [key: string]: string[];
    };
    enumerations: string[];
    id: string;
    execute(rule: RuleInstance, bomRoot: any): RuleInstance | undefined;
    constructor(name: string, code: string, variables: string[], enumerations: string[], behaviour: RuleBehaviour, ruleCode: string);
}
export interface IRunConfiguration {
    withStats?: boolean;
}
export declare class RulesEngine {
    inputRules: RuleStructureInterface[];
    name?: string | undefined;
    version?: string | undefined;
    schemaVersion?: string | undefined;
    validateInputs: string[];
    iterations: number;
    maxIterations: number;
    rules: RuleInstance[];
    id: string;
    constructor(inputRules: RuleStructureInterface[], name?: string | undefined, version?: string | undefined, schemaVersion?: string | undefined, validateInputs?: string[]);
    toJSON(): {
        name: string | undefined;
        version: string | undefined;
        rules: RuleInstance[];
    };
    toObject(): {
        name: string | undefined;
        version: string | undefined;
    };
    runInputValidation(bomRoot: any): void;
    run(withBom: any, configuration?: IRunConfiguration): any;
}
